=============================================
``psyclone.tests.psyir.backend.visitor_test``
=============================================

.. automodule:: psyclone.tests.psyir.backend.visitor_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.backend.visitor_test
